"""! @file filters.py
@brief Filter library for the application
@author xlanro00
"""

import numpy as np
import matplotlib.pyplot as plt
import cv2 as cv


class filter:
    def __init__(self, input_file, output_file, img):
        self.input_file = input_file
        self.output_file = output_file
        self.img = img

class filter_none(filter):
    def __init__(self, input_file, output_file, img):
        super().__init__(input_file, output_file, img)

    def apply(self):
        plt.imshow(self.img)
        print("No filter selected")


class filter_average(filter):
    def __init__(self, input_file, output_file, img):
        super().__init__(input_file, output_file, img)

    def apply(self):
        kernel = np.ones((5, 5), np.float32)/25
        self.img = cv.filter2D(self.img, -1, kernel)
        plt.imshow(self.img)
        print("Average filter")


class filter_blur(filter):
    def __init__(self, input_file, output_file, img):
        super().__init__(input_file, output_file, img)

    def apply(self):
        self.img = cv.blur(self.img, (5, 5))
        plt.imshow(self.img)
        print("Blurring filter")


class filter_gaussian(filter):
    def __init__(self, input_file, output_file, img):
        super().__init__(input_file, output_file, img)

    def apply(self):
        self.img = cv.GaussianBlur(self.img, (5, 5), 0)
        plt.imshow(self.img)
        print("Gaussian filter")
